@@ -85,6 +85,8 @@ setGeneric("pending", function (x) standardGeneric("pending"))
 setGeneric("permissions", function (x) standardGeneric("permissions"))
 setGeneric("members", function (x) standardGeneric("members"))
 setGeneric("members<-", function (x, value) standardGeneric("members<-"))
+setGeneric("multitables", function (x) standardGeneric("multitables"))
+setGeneric("multitables<-", function (x, value) standardGeneric("multitables<-"))
 setGeneric("filters", function (x) standardGeneric("filters"))
 setGeneric("filters<-", function (x, value) standardGeneric("filters<-"))
 setGeneric("appliedFilters", function (x) standardGeneric("appliedFilters"))
@@ -123,10 +125,11 @@ setGeneric("as.vector")
 setGeneric("as.environment")
 setGeneric("dimnames")
 setGeneric("margin.table")
-
 setGeneric("prop.table")
 setGeneric("round")
 
+setGeneric("bases", function (x, margin=NULL) standardGeneric("bases"))
+
 setGeneric("subset")
 setGeneric("which", signature="x")
 
