@@ -10,26 +10,18 @@ test_that("VariableGroup and Order objects can be made", {
 })
 
 with_mock_HTTP({
-    test.ds <- loadDataset("test ds")
-    varcat <- allVariables(test.ds)
+    ds <- loadDataset("test ds")
+    varcat <- allVariables(ds)
 
     test_that("ordering methods on variables catalog", {
-        expect_is(ordering(variables(test.ds)), "VariableOrder")
-        expect_is(ordering(test.ds), "VariableOrder")
-        expect_identical(ordering(variables(test.ds)), ordering(test.ds))
+        expect_is(ordering(variables(ds)), "VariableOrder")
+        expect_is(ordering(ds), "VariableOrder")
+        expect_identical(ordering(variables(ds)), ordering(ds))
     })
 
-    test_that("relative URLs in hierarchical order", {
-        vc <- varcat
-        vc@orders$hier <- sub("hierarchical",
-            "relative-hierarchical", vc@orders$hier)
-        expect_identical(entities(vc@order),
-            entities(VariableOrder(crGET(vc@orders$hier))))
-    })
-
-    test.ord <- ordering(test.ds)
+    test.ord <- ordering(ds)
     ent.urls <- urls(test.ord)
-    varcat_url <- self(allVariables(test.ds))
+    varcat_url <- self(allVariables(ds))
     nested.ord <- try(VariableOrder(
         VariableGroup(name="Group 1",
             entities=list(ent.urls[1],
@@ -38,33 +30,55 @@ with_mock_HTTP({
         VariableGroup(name="Group 2", entities=ent.urls[5:6]),
         catalog_url=varcat_url))
 
+    test_that("Validation on entities<-", {
+        expect_error(entities(ordering(ds)) <- NULL,
+            "NULL is an invalid input for entities")
+        expect_error(entities(nested.ord[[1]]) <- new.env(),
+            "environment is an invalid input for entities")
+    })
+
+    test_that("length methods", {
+        expect_length(nested.ord, 2)
+        expect_length(nested.ord[[1]], 3)
+        expect_length(nested.ord[[2]], 2)
+    })
+
     test_that("Can extract group(s) by name", {
         expect_identical(nested.ord[["Group 2"]],
             VariableGroup(name="Group 2", entities=ent.urls[5:6]))
         expect_identical(nested.ord$`Group 2`,
             VariableGroup(name="Group 2", entities=ent.urls[5:6]))
-        expect_identical(nested.ord["Group 2"],
-            VariableOrder(VariableGroup(name="Group 2",
-            entities=ent.urls[5:6]), catalog_url=varcat_url))
     })
+
+    test_that("Extract with [", {
+        expect_identical(nested.ord["Group 2"],
+            VariableOrder(
+                VariableGroup(name="Group 2", entities=ent.urls[5:6]),
+                catalog_url=varcat_url))
+        expect_error(nested.ord["NOT A GROUP"],
+            "Undefined groups selected: NOT A GROUP")
+    })
+
+    test_that("Extract with [[ from Group", {
+        expect_identical(nested.ord[["Group 1"]]$Nested,
+            VariableGroup(name="Nested", entities=ent.urls[2:3]))
+        expect_error(nested.ord[["Group 1"]][["NOT A GROUP"]],
+            "Undefined groups selected: NOT A GROUP")
+    })
+
+    test_that("Extract with [ from Group", {
+        expect_identical(nested.ord[["Group 1"]]["Nested"],
+            VariableGroup(name="Group 1",
+                entities=list(
+                    VariableGroup(name="Nested", entities=ent.urls[2:3]))))
+        expect_error(nested.ord[["Group 1"]]["NOT A GROUP"],
+            "Undefined groups selected: NOT A GROUP")
+    })
+
     test_that("Can create nested groups", {
         expect_is(nested.ord, "VariableOrder")
         expect_identical(urls(nested.ord), ent.urls)
     })
-    test_that("Can read nested groups from the API", {
-        vc <- varcat
-        vc@orders$hier <- sub("hierarchical",
-            "nested-hierarchical", vc@orders$hier)
-        expect_identical(entities(nested.ord),
-            entities(VariableOrder(crGET(vc@orders$hier))))
-    })
-    test_that("Nested groups can also have relative urls", {
-        vc <- varcat
-        vc@orders$hier <- sub("hierarchical",
-            "relative-and-nested-hierarchical", vc@orders$hier)
-        expect_identical(entities(nested.ord),
-            entities(VariableOrder(crGET(vc@orders$hier))))
-    })
     test_that("Nested groups can serialize and deserialize", {
         vglist <- cereal(nested.ord)
         expect_identical(vglist, list(graph=list(
@@ -191,57 +205,57 @@ with_mock_HTTP({
 
     test_that("Assignment by new group name", {
         nested.o <- nested.ord
-        nested.o[["Group 3"]] <- test.ds["starttime"]
+        nested.o[["Group 3"]] <- ds["starttime"]
         expect_identical(names(nested.o), c("Group 1", "Group 2", "Group 3"))
         expect_identical(entities(nested.o[["Group 3"]]),
-            list(self(test.ds$starttime)))
+            list(self(ds$starttime)))
         ## Test the "duplicates option": starttime should have been removed from
         ## Group 2
         expect_identical(entities(nested.o[["Group 2"]]),
-            list(self(test.ds$catarray)))
+            list(self(ds$catarray)))
     })
 
     test_that("Assignment by new group name with a URL", {
         nested.o <- nested.ord
-        nested.o[["Group 3"]] <- self(test.ds$starttime)
+        nested.o[["Group 3"]] <- self(ds$starttime)
         expect_identical(names(nested.o), c("Group 1", "Group 2", "Group 3"))
         expect_identical(entities(nested.o[["Group 3"]]),
-            list(self(test.ds$starttime)))
+            list(self(ds$starttime)))
         ## Test the "duplicates option": starttime should have been removed from
         ## Group 2
         expect_identical(entities(nested.o[["Group 2"]]),
-            list(self(test.ds$catarray)))
+            list(self(ds$catarray)))
     })
 
     test_that("Assignment by new group name with duplicates", {
         nested.o <- nested.ord
         duplicates(nested.o) <- TRUE
         expect_true(duplicates(nested.o))
-        nested.o[["Group 3"]] <- test.ds["starttime"]
+        nested.o[["Group 3"]] <- ds["starttime"]
         expect_identical(names(nested.o), c("Group 1", "Group 2", "Group 3"))
         expect_identical(entities(nested.o[["Group 3"]]),
-            list(self(test.ds$starttime)))
+            list(self(ds$starttime)))
         ## Test the "duplicates option": starttime should not have been removed
         ## from Group 2
         expect_identical(entities(nested.o[["Group 2"]]),
-            list(self(test.ds$starttime), self(test.ds$catarray)))
+            list(self(ds$starttime), self(ds$catarray)))
     })
 
     test_that("Update group with Dataset", {
         nested.o <- nested.ord
-        nested.o[["Group 2"]] <- test.ds[c("gender", "starttime")]
+        nested.o[["Group 2"]] <- ds[c("gender", "starttime")]
         expect_identical(entities(nested.o[["Group 2"]]),
-            lapply(test.ds[c("gender", "starttime")], self))
+            lapply(ds[c("gender", "starttime")], self))
     })
 
     test_that("Assignment by new nested group name", {
         nested.o <- nested.ord
-        nested.o[["Group 1"]][[2]][["More nesting"]] <- self(test.ds$gender)
+        nested.o[["Group 1"]][[2]][["More nesting"]] <- self(ds$gender)
         expect_identical(entities(nested.o[["Group 1"]]$Nested[["More nesting"]]),
-            list(self(test.ds$gender)))
+            list(self(ds$gender)))
         ## Test duplicates option: gender should only be in "More nesting"
         expect_identical(nested.o[["Group 1"]]$Nested[[1]],
-            self(test.ds$mymrset))
+            self(ds$mymrset))
     })
 
     test_that("Assignment by new nested group name with duplicates", {
@@ -249,12 +263,12 @@ with_mock_HTTP({
         duplicates(nested.o) <- TRUE
         expect_true(duplicates(nested.o[["Group 1"]]))
         expect_true(duplicates(nested.o[["Group 1"]][[2]]))
-        nested.o[["Group 1"]][[2]][["More nesting"]] <- self(test.ds$gender)
+        nested.o[["Group 1"]][[2]][["More nesting"]] <- self(ds$gender)
         expect_identical(entities(nested.o[["Group 1"]]$Nested[["More nesting"]]),
-            list(self(test.ds$gender)))
+            list(self(ds$gender)))
         ## Test duplicates option: gender should still be in "More nesting"
         expect_identical(nested.o[["Group 1"]]$Nested[[1]],
-            self(test.ds$gender))
+            self(ds$gender))
         ## Test that duplicates option passes to new group
         expect_true(duplicates(nested.o[["Group 1"]][[2]][["More nesting"]]))
     })
@@ -275,6 +289,12 @@ with_mock_HTTP({
         expect_identical(entities(nested.o[[1]]), as.list(ent.urls))
     })
 
+    ds3 <- loadDataset("ECON.sav")
+    test_that("Show method for VO handles relative URLs correctly", {
+        expect_output(ordering(ds3),
+            "Gender\nBirth Year\nstarttime")
+    })
+
     test_that("VariableOrder/Group show methods", {
         expect_output(nested.ord,
             paste("[+] Group 1",
@@ -306,8 +326,8 @@ with_mock_HTTP({
             fixed=TRUE)
     })
 
-    ord <- test.ord
-    test_that("Composing a VariableOrder step by step: setup", {
+    ord <- flattenOrder(test.ord)
+    test_that("Composing a VariableOrder step by step: setup (flattenOrder)", {
         expect_output(ord,
             paste("Birth Year",
                   "Gender",
@@ -319,7 +339,7 @@ with_mock_HTTP({
             fixed=TRUE)
     })
     test_that("Composing a VariableOrder step by step: group 1 by dataset", {
-        ord$Demos <<- test.ds[c("gender", "birthyr")]
+        ord$Demos <<- ds[c("gender", "birthyr")]
         expect_output(ord,
             paste("mymrset",
                   "Text variable ftw",
@@ -332,7 +352,7 @@ with_mock_HTTP({
             fixed=TRUE)
     })
     test_that("Composing a VariableOrder step by step: group by Order subset", {
-        ord$Arrays <<- ord[c(1, 4)] #test.ds[c("mymrset", "catarray")]
+        ord$Arrays <<- ord[c(1, 4)] #ds[c("mymrset", "catarray")]
         expect_output(ord,
             paste("Text variable ftw",
                   "starttime",
@@ -346,7 +366,7 @@ with_mock_HTTP({
             fixed=TRUE)
     })
     test_that("Composing a VariableOrder step by step: nested group by dataset", {
-        ord$Demos[["Others"]] <<- test.ds[c("birthyr", "textVar")]
+        ord$Demos[["Others"]] <<- ds[c("birthyr", "textVar")]
         expect_output(ord,
             paste("starttime",
                   "[+] Demos",
@@ -407,198 +427,407 @@ with_mock_HTTP({
             fixed=TRUE)
     })
 
-    test_that("Show method for VO handles relative URLs correctly", {
-        ds3 <- loadDataset("ECON.sav")
-        expect_output(ordering(ds3),
-            "Gender\nBirth Year\nstarttime")
+    test_that("Order print method follows namekey", {
+        with(temp.option(crunch.namekey.variableorder="alias"), {
+            expect_output(ord,
+                paste("[+] Arrays",
+                      "    catarray",
+                      "    [+] MR",
+                      "        mymrset",
+                      "[+] Demos",
+                      "    [+] Others",
+                      "        birthyr",
+                      "        textVar",
+                      "    gender",
+                      "starttime",
+                      sep="\n"),
+                fixed=TRUE)
+        })
+    })
+
+    test_that("locateEntity", {
+        expect_identical(locateEntity(ds$mymrset, ord),
+            c("Arrays", "MR"))
+        expect_identical(locateEntity(ds$gender, ord),
+            "Demos")
+        expect_length(locateEntity(ds$starttime, ord), 0)
+        expect_true(is.na(locateEntity(ds3$gender, ord)))
+    })
+
+    test_that("Composing a VariableOrder step by step: moveToGroup", {
+        moveToGroup(ord$Demos$Others) <<- ds$starttime
+        expect_output(ord,
+            paste("[+] Arrays",
+                  "    Cat Array",
+                  "    [+] MR",
+                  "        mymrset",
+                  "[+] Demos",
+                  "    [+] Others",
+                  "        Birth Year",
+                  "        Text variable ftw",
+                  "        starttime",
+                  "    Gender",
+                  sep="\n"),
+            fixed=TRUE)
+    })
+
+    test_that("moveToGroup with groups", {
+        moveToGroup(ord$Demos) <<- ord$Arrays
+        ord <- removeEmptyGroups(ord)
+        expect_output(ord,
+            paste("[+] Demos",
+                  "    [+] Others",
+                  "        Birth Year",
+                  "        Text variable ftw",
+                  "        starttime",
+                  "    Gender",
+                  "    [+] Arrays",
+                  "        Cat Array",
+                  "        [+] MR",
+                  "            mymrset",
+                  sep="\n"),
+            fixed=TRUE)
+    })
+    test_that("moveToGroup with dataset subset", {
+        moveToGroup(ord$Demos$Arrays) <<- ds[c("birthyr", "gender")]
+        ord <- removeEmptyGroups(ord)
+        expect_output(ord,
+            paste("[+] Demos",
+                  "    [+] Others",
+                  "        Text variable ftw",
+                  "        starttime",
+                  "    [+] Arrays",
+                  "        Cat Array",
+                  "        [+] MR",
+                  "            mymrset",
+                  "        Birth Year",
+                  "        Gender",
+                  sep="\n"),
+            fixed=TRUE)
+    })
+    test_that("flattenOrder on that composed order", {
+        expect_output(flattenOrder(ord),
+            paste("Text variable ftw",
+                  "starttime",
+                  "Cat Array",
+                  "mymrset",
+                  "Birth Year",
+                  "Gender",
+                  sep="\n"),
+            fixed=TRUE)
+    })
+
+    ord <- VariableOrder(
+        VariableGroup("Alpha", list(
+            self(ds$gender),
+            VariableGroup("Bravo", list(
+                self(ds$gender),
+                VariableGroup("Charlie", ds[c("gender", "birthyr")]),
+                self(ds$mymrset))),
+            ds$birthyr)),
+        VariableGroup("Delta", list(
+            self(ds$gender),
+            self(ds$mymrset),
+            VariableGroup("Echo", list(
+                VariableGroup("Foxtrot", ds[c("birthyr", "catarray")]),
+                self(ds$starttime),
+                self(ds$starttime))),
+            self(ds$starttime))),
+        self(ds$gender),
+        self(ds$textVar),
+        self(ds$birthyr),
+        duplicates=TRUE,
+        catalog_url=varcat_url
+    )
+    test_that("Complex order with duplicates", {
+        expect_output(ord,
+            paste("[+] Alpha",
+                  "    Gender",
+                  "    [+] Bravo",
+                  "        Gender",
+                  "        [+] Charlie",
+                  "            Gender",
+                  "            Birth Year",
+                  "        mymrset",
+                  "    Birth Year",
+                  "[+] Delta",
+                  "    Gender",
+                  "    mymrset",
+                  "    [+] Echo",
+                  "        [+] Foxtrot",
+                  "            Birth Year",
+                  "            Cat Array",
+                  "        starttime",
+                  "        starttime",
+                  "    starttime",
+                  "Gender",
+                  "Text variable ftw",
+                  "Birth Year",
+                  sep="\n"),
+            fixed=TRUE)
+    })
+    test_that("dedupeOrder removes duplicate entries", {
+        expect_output(dedupeOrder(ord),
+            paste("[+] Alpha",
+                  "    [+] Bravo",
+                  "        [+] Charlie",
+                  "            Gender",
+                  "            Birth Year",
+                  "        mymrset",
+                  "[+] Delta",
+                  "    [+] Echo",
+                  "        [+] Foxtrot",
+                  "            Cat Array",
+                  "        starttime",
+                  "Text variable ftw",
+                  sep="\n"),
+            fixed=TRUE)
+    })
+    test_that("dedupeOrder doesn't mutate an order that's already deduped", {
+        expect_output(dedupeOrder(dedupeOrder(ord)),
+            paste("[+] Alpha",
+                  "    [+] Bravo",
+                  "        [+] Charlie",
+                  "            Gender",
+                  "            Birth Year",
+                  "        mymrset",
+                  "[+] Delta",
+                  "    [+] Echo",
+                  "        [+] Foxtrot",
+                  "            Cat Array",
+                  "        starttime",
+                  "Text variable ftw",
+                  sep="\n"),
+            fixed=TRUE)
+    })
+    test_that("Setting duplicates <- FALSE triggers dedupeOrder", {
+        duplicates(ord) <- FALSE
+        expect_output(ord,
+            paste("[+] Alpha",
+                  "    [+] Bravo",
+                  "        [+] Charlie",
+                  "            Gender",
+                  "            Birth Year",
+                  "        mymrset",
+                  "[+] Delta",
+                  "    [+] Echo",
+                  "        [+] Foxtrot",
+                  "            Cat Array",
+                  "        starttime",
+                  "Text variable ftw",
+                  sep="\n"),
+            fixed=TRUE)
+    })
+    test_that("intersect_entities", {
+        expect_output(intersect_entities(ord, ds[c("birthyr", "starttime")]),
+            paste("[+] Alpha",
+                  "    [+] Bravo",
+                  "        [+] Charlie",
+                  "            Birth Year",
+                  "    Birth Year",
+                  "[+] Delta",
+                  "    [+] Echo",
+                  "        [+] Foxtrot",
+                  "            Birth Year",
+                  "        starttime",
+                  "        starttime",
+                  "    starttime",
+                  "Birth Year",
+                  sep="\n"),
+            fixed=TRUE)
     })
 })
 
 
-if (run.integration.tests) {
-    with_test_authentication({
-        with(test.dataset(df), {
-            test_that("Can get VariableOrder from dataset", {
-                expect_true(setequal(unlist(entities(ordering(ds))),
-                    urls(allVariables(ds))))
-            })
-            test_that("Can construct VariableOrder from variables", {
-                vg <- VariableOrder(
-                    VariableGroup(name="Group 1",
-                        variables=ds[c("v1", "v3", "v5")]),
-                    VariableGroup(name="Group 2.5", entities=ds["v4"]),
-                    VariableGroup(name="Group 2",
-                        entities=ds[c("v6", "v2")]))
-                vglist <- cereal(vg)
-                expect_identical(vglist, list(graph=list(
-                    list(`Group 1`=list(self(ds$v1), self(ds$v3), self(ds$v5))),
-                    list(`Group 2.5`=list(self(ds$v4))),
-                    list(`Group 2`=list(self(ds$v6), self(ds$v2)))
-                )))
-            })
-            starting.vg <- vg <- VariableOrder(
-                VariableGroup(name="Group 1",
-                    entities=ds[c("v1", "v3", "v5")]),
-                VariableGroup(name="Group 2.5", variables=ds["v4"]),
-                VariableGroup(name="Group 2",
-                    entities=ds[c("v6", "v2")]),
-                duplicates=TRUE)
-
-            test_that("Get urls from VariableOrder and Group", {
-                expect_identical(urls(vg[[1]]),
-                    c(self(ds$v1), self(ds$v3), self(ds$v5)))
-                expect_identical(urls(vg),
-                    c(self(ds$v1), self(ds$v3), self(ds$v5), self(ds$v4),
-                    self(ds$v6), self(ds$v2)))
-            })
-
-            try(entities(vg[[2]]) <- self(ds$v2))
-            test_that("Set URLs -> entities on VariableGroup", {
-                expect_identical(urls(vg[[2]]), self(ds$v2))
-                expect_identical(urls(vg),
-                    c(self(ds$v1), self(ds$v3), self(ds$v5), self(ds$v2),
-                    self(ds$v6)))
-            })
-            try(entities(vg[[2]]) <- list(ds$v3))
-            test_that("Set variables -> entities on VariableGroup", {
-                expect_identical(urls(vg[[2]]), self(ds$v3))
-            })
-
-            try(name(vg[[2]]) <- "Group 3")
-            test_that("Set name on VariableGroup", {
-                expect_identical(names(vg), c("Group 1", "Group 3", "Group 2"))
-            })
-            try(names(vg) <- c("G3", "G1", "G2"))
-            test_that("Set names on VariableOrder", {
-                expect_identical(names(vg), c("G3", "G1", "G2"))
-            })
-
-            try(vglist <- cereal(vg))
-            test_that("VariableOrder to/fromJSON", {
-                expect_identical(vglist, list(graph=list(
-                    list(`G3`=list(self(ds$v1), self(ds$v3), self(ds$v5))),
-                    list(`G1`=list(self(ds$v3))),
-                    list(`G2`=list(self(ds$v6), self(ds$v2)))
-                )))
-
-                vg[1:2] <- vg[c(2,1)]
-                expect_identical(cereal(vg), list(graph=list(
-                    list(`G1`=list(self(ds$v3))),
-                    list(`G3`=list(self(ds$v1), self(ds$v3), self(ds$v5))),
-                    list(`G2`=list(self(ds$v6), self(ds$v2)))
-                )))
-            })
-
-            original.order <- ordering(ds)
-            test_that("Can set VariableOrder on dataset", {
-                expect_false(identical(starting.vg, original.order))
-                ordering(ds) <- starting.vg
-                expect_identical(entities(grouped(ordering(ds))),
-                    entities(starting.vg))
-                expect_identical(entities(grouped(ordering(refresh(ds)))),
-                    entities(starting.vg))
-                expect_is(ungrouped(ordering(ds)), "VariableGroup")
-                expect_is(ungrouped(ordering(refresh(ds))), "VariableGroup")
-                expect_identical(names(ordering(ds)),
-                    c("Group 1", "Group 2.5", "Group 2"))
-
-                ## Test that can reorder groups
-                ordering(ds) <- starting.vg[c(2,1,3)]
-                expect_identical(entities(grouped(ordering(ds))),
-                    entities(starting.vg[c(2,1,3)]))
-                expect_identical(names(ordering(ds)),
-                    c("Group 2.5", "Group 1", "Group 2"))
-                expect_identical(names(ordering(refresh(ds))),
-                    c("Group 2.5", "Group 1", "Group 2"))
-
-                ds <- refresh(ds)
-                expect_false(identical(entities(ordering(variables(ds))),
-                    entities(original.order)))
-                ordering(variables(ds)) <- original.order
-                expect_identical(entities(ordering(variables(ds))),
-                    entities(original.order))
-                expect_identical(entities(ordering(variables(refresh(ds)))),
-                    entities(original.order))
-            })
-
-            test_that("A partial order results in 'ungrouped' variables", {
-                ordering(ds) <- starting.vg[1:2]
-                expect_is(grouped(ordering(ds)), "VariableOrder")
-                expect_identical(entities(grouped(ordering(ds))),
-                    entities(starting.vg[1:2]))
-                expect_is(ungrouped(ordering(ds)), "VariableGroup")
-                expect_true(setequal(unlist(entities(ungrouped(ordering(ds)))),
-                    c(self(ds$v6), self(ds$v2))))
-            })
-
-            test_that("grouped and ungrouped within a group", {
-                nesting <- VariableGroup("Nest", self(ds$v3))
-                ordering(ds) <- starting.vg
-                ordering(ds)[["Group 1"]][[2]] <- nesting
-                ## Update fixture with duplicates=TRUE, as it should be found
-                ## after setting on a duplicates=TRUE order
-                duplicates(nesting) <- TRUE
-                expect_identical(grouped(ordering(ds)[["Group 1"]]),
-                    VariableGroup("Group 1", list(nesting), duplicates=TRUE))
-                expect_identical(ungrouped(ordering(ds)[["Group 1"]]),
-                    VariableGroup("ungrouped", list(self(ds$v1), self(ds$v5))))
-            })
-
-            test_that("Can manipulate VariableOrder that's part of a dataset", {
-                ordering(ds) <- starting.vg
-                expect_identical(names(ordering(ds)),
-                    c("Group 1", "Group 2.5", "Group 2"))
-                names(ordering(ds))[3] <- "Three"
-                expect_identical(names(ordering(ds)),
-                    c("Group 1", "Group 2.5", "Three"))
-                expect_identical(names(grouped(ordering(ds))),
-                    c("Group 1", "Group 2.5", "Three"))
-            })
-
-            test_that("duplicates property: setup", {
-                expect_false(duplicates(ordering(ds)))
-            })
-            test_that("duplicates property set on order in dataset", {
-                duplicates(ordering(ds)) <<- TRUE
-                expect_true(duplicates(ordering(ds)))
-            })
-            test_that("duplicates property persists on refreshing dataset", {
-                expect_true(duplicates(ordering(refresh(ds))))
-            })
-            ord <- ordering(ds)
-            test_that("duplicates property persists on extracting order", {
-                expect_true(duplicates(ord))
-            })
-            test_that("duplicates property persists on refreshing order", {
-                skip("refresh method for VariableOrder not implemented")
-                expect_true(duplicates(refresh(ord)))
-            })
-            test_that("duplicates property from order is set on assign to ds", {
-                duplicates(ordering(ds)) <<- FALSE
-                expect_false(duplicates(ordering(ds)))
-                ordering(ds) <<- ord
-                expect_true(duplicates(ordering(ds)))
-            })
-
-            test_that("ordering<- validation", {
-                bad.vg <- starting.vg
-                entities(bad.vg[[1]]) <- c(entities(bad.vg[[1]])[-2],
-                    "/not/a/variable")
-                expect_error(ordering(ds) <- bad.vg,
-                    "Variable URL referenced in Order not present in catalog: /not/a/variable")
-            })
-
-            test_that("Creating VariableOrder with named list doesn't break", {
-                bad.vg <- do.call(VariableOrder, c(sapply(names(starting.vg),
-                    function (i) starting.vg[[i]], simplify=FALSE),
-                    duplicates=TRUE))
-                ## The list of entities is named because sapply default is
-                ## USE.NAMES=TRUE, but the VariableOrder constructor should
-                ## handle this
-                ordering(ds) <- bad.vg
-                expect_identical(ordering(ds)@graph,
-                    starting.vg@graph)
-            })
-        })
+with_test_authentication({
+    ds <- newDataset(df)
+    test_that("Can get VariableOrder from dataset", {
+        expect_true(setequal(unlist(entities(ordering(ds))),
+            urls(allVariables(ds))))
     })
-}
+    test_that("Can construct VariableOrder from variables", {
+        vg <- VariableOrder(
+            VariableGroup(name="Group 1",
+                variables=ds[c("v1", "v3", "v5")]),
+            VariableGroup(name="Group 2.5", entities=ds["v4"]),
+            VariableGroup(name="Group 2",
+                entities=ds[c("v6", "v2")]))
+        vglist <- cereal(vg)
+        expect_identical(vglist, list(graph=list(
+            list(`Group 1`=list(self(ds$v1), self(ds$v3), self(ds$v5))),
+            list(`Group 2.5`=list(self(ds$v4))),
+            list(`Group 2`=list(self(ds$v6), self(ds$v2)))
+        )))
+    })
+    starting.vg <- vg <- VariableOrder(
+        VariableGroup(name="Group 1",
+            entities=ds[c("v1", "v3", "v5")]),
+        VariableGroup(name="Group 2.5", variables=ds["v4"]),
+        VariableGroup(name="Group 2",
+            entities=ds[c("v6", "v2")]),
+        duplicates=TRUE)
+
+    test_that("Get urls from VariableOrder and Group", {
+        expect_identical(urls(vg[[1]]),
+            c(self(ds$v1), self(ds$v3), self(ds$v5)))
+        expect_identical(urls(vg),
+            c(self(ds$v1), self(ds$v3), self(ds$v5), self(ds$v4),
+            self(ds$v6), self(ds$v2)))
+    })
+
+    try(entities(vg[[2]]) <- self(ds$v2))
+    test_that("Set URLs -> entities on VariableGroup", {
+        expect_identical(urls(vg[[2]]), self(ds$v2))
+        expect_identical(urls(vg),
+            c(self(ds$v1), self(ds$v3), self(ds$v5), self(ds$v2),
+            self(ds$v6)))
+    })
+    try(entities(vg[[2]]) <- list(ds$v3))
+    test_that("Set variables -> entities on VariableGroup", {
+        expect_identical(urls(vg[[2]]), self(ds$v3))
+    })
+
+    try(name(vg[[2]]) <- "Group 3")
+    test_that("Set name on VariableGroup", {
+        expect_identical(names(vg), c("Group 1", "Group 3", "Group 2"))
+    })
+    try(names(vg) <- c("G3", "G1", "G2"))
+    test_that("Set names on VariableOrder", {
+        expect_identical(names(vg), c("G3", "G1", "G2"))
+    })
+
+    try(vglist <- cereal(vg))
+    test_that("VariableOrder to/fromJSON", {
+        expect_identical(vglist, list(graph=list(
+            list(`G3`=list(self(ds$v1), self(ds$v3), self(ds$v5))),
+            list(`G1`=list(self(ds$v3))),
+            list(`G2`=list(self(ds$v6), self(ds$v2)))
+        )))
+
+        vg[1:2] <- vg[c(2,1)]
+        expect_identical(cereal(vg), list(graph=list(
+            list(`G1`=list(self(ds$v3))),
+            list(`G3`=list(self(ds$v1), self(ds$v3), self(ds$v5))),
+            list(`G2`=list(self(ds$v6), self(ds$v2)))
+        )))
+    })
+
+    original.order <- ordering(ds)
+    test_that("Can set VariableOrder on dataset", {
+        expect_false(identical(starting.vg, original.order))
+        ordering(ds) <- starting.vg
+        expect_identical(entities(grouped(ordering(ds))),
+            entities(starting.vg))
+        expect_identical(entities(grouped(ordering(refresh(ds)))),
+            entities(starting.vg))
+        expect_is(ungrouped(ordering(ds)), "VariableGroup")
+        expect_is(ungrouped(ordering(refresh(ds))), "VariableGroup")
+        expect_identical(names(ordering(ds)),
+            c("Group 1", "Group 2.5", "Group 2"))
+
+        ## Test that can reorder groups
+        ordering(ds) <- starting.vg[c(2,1,3)]
+        expect_identical(entities(grouped(ordering(ds))),
+            entities(starting.vg[c(2,1,3)]))
+        expect_identical(names(ordering(ds)),
+            c("Group 2.5", "Group 1", "Group 2"))
+        expect_identical(names(ordering(refresh(ds))),
+            c("Group 2.5", "Group 1", "Group 2"))
+
+        ds <- refresh(ds)
+        expect_false(identical(entities(ordering(variables(ds))),
+            entities(original.order)))
+        ordering(variables(ds)) <- original.order
+        expect_identical(entities(ordering(variables(ds))),
+            entities(original.order))
+        expect_identical(entities(ordering(variables(refresh(ds)))),
+            entities(original.order))
+    })
+
+    test_that("A partial order results in 'ungrouped' variables", {
+        ordering(ds) <- starting.vg[1:2]
+        expect_is(grouped(ordering(ds)), "VariableOrder")
+        expect_identical(entities(grouped(ordering(ds))),
+            entities(starting.vg[1:2]))
+        expect_is(ungrouped(ordering(ds)), "VariableGroup")
+        expect_true(setequal(unlist(entities(ungrouped(ordering(ds)))),
+            c(self(ds$v6), self(ds$v2))))
+    })
+
+    test_that("grouped and ungrouped within a group", {
+        nesting <- VariableGroup("Nest", self(ds$v3))
+        ordering(ds) <- starting.vg
+        ordering(ds)[["Group 1"]][[2]] <- nesting
+        ## Update fixture with duplicates=TRUE, as it should be found
+        ## after setting on a duplicates=TRUE order
+        duplicates(nesting) <- TRUE
+        expect_identical(grouped(ordering(ds)[["Group 1"]]),
+            VariableGroup("Group 1", list(nesting), duplicates=TRUE))
+        expect_identical(ungrouped(ordering(ds)[["Group 1"]]),
+            VariableGroup("ungrouped", list(self(ds$v1), self(ds$v5))))
+    })
+
+    test_that("Can manipulate VariableOrder that's part of a dataset", {
+        ordering(ds) <- starting.vg
+        expect_identical(names(ordering(ds)),
+            c("Group 1", "Group 2.5", "Group 2"))
+        names(ordering(ds))[3] <- "Three"
+        expect_identical(names(ordering(ds)),
+            c("Group 1", "Group 2.5", "Three"))
+        expect_identical(names(grouped(ordering(ds))),
+            c("Group 1", "Group 2.5", "Three"))
+    })
+
+    test_that("duplicates property: setup", {
+        expect_false(duplicates(ordering(ds)))
+    })
+    test_that("duplicates property set on order in dataset", {
+        duplicates(ordering(ds)) <<- TRUE
+        expect_true(duplicates(ordering(ds)))
+    })
+    test_that("duplicates property persists on refreshing dataset", {
+        expect_true(duplicates(ordering(refresh(ds))))
+    })
+    ord <- ordering(ds)
+    test_that("duplicates property persists on extracting order", {
+        expect_true(duplicates(ord))
+    })
+    test_that("duplicates property persists on refreshing order", {
+        skip("refresh method for VariableOrder not implemented")
+        expect_true(duplicates(refresh(ord)))
+    })
+    test_that("duplicates property from order is set on assign to ds", {
+        duplicates(ordering(ds)) <<- FALSE
+        expect_false(duplicates(ordering(ds)))
+        ordering(ds) <<- ord
+        expect_true(duplicates(ordering(ds)))
+    })
+
+    test_that("ordering<- validation", {
+        bad.vg <- starting.vg
+        entities(bad.vg[[1]]) <- c(entities(bad.vg[[1]])[-2],
+            "/not/a/variable")
+        expect_error(ordering(ds) <- bad.vg,
+            "Variable URL referenced in Order not present in catalog: /not/a/variable")
+    })
+
+    test_that("Creating VariableOrder with named list doesn't break", {
+        bad.vg <- do.call(VariableOrder, c(sapply(names(starting.vg),
+            function (i) starting.vg[[i]], simplify=FALSE),
+            duplicates=TRUE))
+        ## The list of entities is named because sapply default is
+        ## USE.NAMES=TRUE, but the VariableOrder constructor should
+        ## handle this
+        ordering(ds) <- bad.vg
+        expect_identical(ordering(ds)@graph, starting.vg@graph)
+    })
+
+    ordering(ds) <- starting.vg
+    duplicates(ordering(ds)) <- FALSE
+    test_that("moveToGroup<-", {
+        expect_identical(urls(ordering(ds)[["Group 2.5"]]), self(ds$v4))
+        moveToGroup(ordering(ds)[["Group 2.5"]]) <- ds["v6"]
+        expect_identical(urls(ordering(ds)[["Group 2.5"]]),
+            urls(variables(ds[c("v4", "v6")])))
+    })
+})
